<!-- extend base layout -->
{% extends "appbuilder/base.html" %}
{% import 'appbuilder/general/lib.html' as lib %}

{% block content %}
{{ lib.render_title(title) }}

<form action="" method="post">
	{{form.hidden_tag()}}
	<table class="table table-bordered">
	{% for item in edit_columns %}
		{% set field = form | get_attr(item) %}
			<tr>
			{{ lib.render_field(field) }}
			</tr>
	{% endfor %}
	</table>

	<div class="control-group navbar">
                <div class="controls navbar-inner">
                        <button type="submit" class="btn btn-primary">Reset Password</button>
			<INPUT Type="button" class="btn btn-primary" VALUE="Back" onClick="history.go(-1);return true;">
                </div>
        </div>

</form>
{% endblock %}


